/*
 * Author: Neil Kolban
 * Date: 7/3/2002
 * 
 * ListQueues
 * ----------
 * This application demonstrates the use of PCF messages to query
 * the names of all the queues at the queue manager.  The list of
 * queues is displayed on the console.
 * 
 * Usage: SimpleResponse RequestQName [QmgrName]
 * 
 */
using System;
using MQ;
using MQ.PCF;

namespace ListQueues
{
	/// <summary>
	/// This sample lists the queues at the named queue manager.
	/// Usage: ListQueues QueueManagerName
	/// </summary>
	class ListQueues
	{
		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main(string[] args)
		{
			if (args.Length < 1)
			{
				Console.WriteLine("Usage: ListQueues QueueManagerName");
				return;
			}
			string queueManagerName = args[0];
			try
			{
				// Build an agent for the query.
				PCFMessageAgent agent = new PCFMessageAgent(queueManagerName);

				// Build the query request.
				PCFMessage requestMessage = new PCFMessage(CMQCFC.MQCMD_INQUIRE_Q_NAMES);
				requestMessage.AddParameter(MQC.MQCA_Q_NAME, "*");

				// Send the request and retrieve the response.
				PCFMessage [] responses = agent.Send(requestMessage);

				// Retrieve the values requested from the response.
				string [] queueNames = responses[0].GetStringListParameterValue(CMQCFC.MQCACF_Q_NAMES);

				// Display the values.
				for (int i=0; i<queueNames.Length; i++)
				{
					Console.WriteLine("Queue: {0}", queueNames[i]);
				}
			}
			catch(MQException e)
			{
				Console.WriteLine("Exception: " + e.ToString());
			}
		}
	}
}
