/*
 * Author: Neil Kolban
 * Date: 6/27/2002
 * 
 * SimplePut
 * ---------
 * This application demonstrates putting messages to an MQSeries queue from
 * a C# application in the .NET framework.
 * 
 * The application reads lines of text from the console and, for each line,
 * writes it as a unique message to a queue.
 * 
 * The name of the queue and queue manager are supplied as parameters on the
 * command line.
 * 
 * Usage: SimplePut QName [QmgrName]
 * 
 */
using System;
using MQ;

namespace MQSamples
{
	/// <summary>
	/// Put console lines as messages to a queue.
	/// </summary>
	class SimplePut
	{
		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main(string[] args)
		{
			if (args.Length == 0)
			{
				Console.WriteLine("Usage: SimplePut QName [QMgrName]");
				return;
			}
			string qName = args[0];
			string qMgrName = "";
			if (args.Length > 1)
			{
				qMgrName = args[1];
			}

			try
			{
				Console.WriteLine("Sample SimplePut started");
				MQQueueManager qMgr = new MQQueueManager(qMgrName);
				MQQueue queue = qMgr.AccessQueue(qName, MQC.MQOO_OUTPUT);
				string line;
				do
				{
					line = Console.ReadLine();
					if (line.Length > 0)
					{
						MQMessage message = new MQMessage();
						message.WriteString(line);
						message.Format = MQC.MQFMT_STRING;
						queue.Put(message);
					}

				} while (line.Length > 0);
				queue.Close();
				qMgr.Disconnect();
			}
			catch(MQException e)
			{
				Console.WriteLine("Error: {0}", e.ToString());
			}
		}
	}
}
