/*
 * Author: Neil Kolban
 * Date: 6/27/2002
 * 
 * SimpleResponse
 * --------------
 * This application demonstrates responding to a request message.  The
 * program blocks waiting for a message, when received, it responds to
 * the request and then blocks again waiting for the next request.
 * 
 * Usage: SimpleResponse RequestQName [QmgrName]
 */
using System;
using MQ;

namespace MQSamples
{
	/// <summary>
	/// Summary description for Class1.
	/// </summary>
	class SimpleResponse
	{
		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main(string[] args)
		{
			if (args.Length < 1)
			{
				Console.WriteLine("Usage: SimpleResponse RequestQName [QmgrName]");
				return;
			}
			string requestQName = args[0];
			string qMgrName = "";
			if (args.Length > 1)
			{
				qMgrName = args[1];
			}

			try
			{
				Console.WriteLine("Sample SimpleResponse started.");

				MQQueueManager qMgr = new MQQueueManager(qMgrName);
				MQQueue requestQueue = qMgr.AccessQueue(requestQName, MQC.MQOO_INPUT_AS_Q_DEF);
				MQMessage requestMessage = new MQMessage();
				MQGetMessageOptions gmo = new MQGetMessageOptions();
				gmo.Options = MQC.MQGMO_WAIT;
				gmo.WaitInterval = MQC.MQWI_UNLIMITED;
				gmo.MatchOptions = MQC.MQMO_NONE;

				MQPutMessageOptions pmo = new MQPutMessageOptions();

				while (true)
				{
					requestQueue.Get(requestMessage, gmo);
					string line = requestMessage.ReadString(requestMessage.MessageLength);
					Console.WriteLine("Received: {0}", line);
					if (line.Equals("END"))
					{
						break;
					}
				///
				/// Send the response message.
				/// 
					MQQueue responseQueue = qMgr.AccessQueue(
						requestMessage.ReplyToQName,
						MQC.MQOO_OUTPUT,
						requestMessage.ReplyToQMgrName,
						null, null);

					MQMessage responseMessage = new MQMessage();
					pmo.Options = MQC.MQPMO_NONE;

					///
					/// A large number of MQSeries based applications are
					/// hard coded to process the MsgId and CorrelId in
					/// request and reply processing.  This section of code
					/// honors the request message Report field and the
					/// options contained within.
					/// 
					if ((requestMessage.Report & MQC.MQRO_PASS_MSG_ID) == MQC.MQRO_PASS_MSG_ID)
					{
						responseMessage.MsgId = requestMessage.CorrelId;
					}
					else // Assume MQRO_NEW_MSG_ID
					{
						pmo.Options = MQC.MQPMO_NEW_MSG_ID;
					}

					if ((requestMessage.Report & MQC.MQRO_PASS_CORREL_ID) == MQC.MQRO_PASS_CORREL_ID)
					{
						responseMessage.CorrelId = requestMessage.CorrelId;
					}
					else // Assume MQRO_COPY_MSG_ID_TO_CORREL_ID
					{
						responseMessage.CorrelId = requestMessage.MsgId;
					}

					responseMessage.MessageType = MQC.MQMT_REPLY;
					responseMessage.WriteString("This is the response");

					responseQueue.Put(responseMessage);
					responseQueue.Close();
				}
				requestQueue.Close();
				qMgr.Disconnect();
			}
			catch(MQException e)
			{
				Console.WriteLine("Error: {0}", e.ToString());
			}
		}
	}
}
